function [ ranking ] = supINFFS( NEG, POS )

% Preprocessing
mu_NEG = mean(NEG);
mu_POS = mean(POS);

% Metric 1: T-Test
[h,scores] = ttest2(full(NEG),full(POS));
scores(h==0)=1; % Rejection
scores(isnan(scores)) = 1;
ttest_s=1-scores;

%Metric 2: Correlation
Y_train = [ones(size(POS,1),1); -ones(size(NEG,1),1);];
X_train = [POS;NEG];
perm = randperm(length(Y_train));
[corr_s,PVAL] = corr(X_train(perm,:),Y_train(perm));
corr_s(PVAL>0.05) = 0;
corr_s(isnan(corr_s)) = 0;

% Metric 4: Fisher criterion
fisher_s = ([mu_POS - mu_NEG].^2);
st   = std(POS).^2;
st   = st+std(NEG).^2;
f=find(st==0); %% remove ones where nothing occurs
st(f)=10000;  %% remove ones where nothing occurs
fisher_s = fisher_s ./ st;
fisher_s = (fisher_s-min(fisher_s))/max((fisher_s-min(fisher_s)));

% Building the graph
Kernel = [(abs(fisher_s + ttest_s + corr_s')/3)'*(abs(fisher_s + ttest_s + corr_s')/3) ] ;

% Inf-FS
I = eye( size( Kernel ,1 )); % Identity Matrix
[~, eigval] = eigs(double(Kernel),1,'lm');
[~ , ranking ]= sort( sum( inv( I - ( (0.9/eigval) * Kernel ) ) - I , 2 ) , 'descend' );

end

